@@ -1,9 +1,10 @@
 from functools import wraps
 from django.core.urlresolvers import reverse
-from django.http import HttpResponseRedirect
+from django.http import HttpResponseRedirect, HttpResponse
+from django.shortcuts import get_object_or_404
 
 from sentry.conf import settings
-from sentry.models import Project, Team
+from sentry.models import Project, Team, Group
 from sentry.web.helpers import get_project_list, render_to_response, \
   get_login_url, get_team_list
 
@@ -33,6 +34,7 @@ def has_access(group_or_func=None):
             # If we're asking for anything other than implied access, the user
             # must be authenticated
             if group_or_func and not request.user.is_authenticated():
+                request.session['_next'] = request.build_absolute_uri()
                 return HttpResponseRedirect(get_login_url())
 
             # XXX: if project_id isn't set, should we only allow superuser?
@@ -59,6 +61,7 @@ def has_access(group_or_func=None):
                             return HttpResponseRedirect(reverse('sentry'))
                 else:
                     project = None
+
                 return func(request, project, *args, **kwargs)
 
             if project_id:
@@ -116,11 +119,37 @@ def has_team_access(group_or_func=None):
     return wrapped
 
 
+def has_group_access(func):
+    """
+    Tests and transforms project_id and group_id for permissions based on
+    the requesting user. Passes the actual project and group instances to
+    the decorated view.
+
+    >>> @has_group_access
+    >>> def foo(request, project, group):
+    >>>     return
+    """
+    prv_func = login_required(has_access(func))
+
+    @wraps(func)
+    def wrapped(request, project_id, group_id, *args, **kwargs):
+        group = get_object_or_404(Group, pk=group_id)
+
+        if group.project and project_id not in (group.project.slug, str(group.project.id)):
+            return HttpResponse(status=404)
+
+        if group.is_public:
+            return func(request, group.project, group, *args, **kwargs)
+        return prv_func(request, group.project.slug, group, *args, **kwargs)
+    return wrapped
+
+
 def login_required(func):
     @wraps(func)
     def wrapped(request, *args, **kwargs):
         if not settings.PUBLIC:
             if not request.user.is_authenticated():
+                request.session['_next'] = request.build_absolute_uri()
                 return HttpResponseRedirect(get_login_url())
         return func(request, *args, **kwargs)
     return wrapped
@@ -130,6 +159,7 @@ def requires_admin(func):
     @wraps(func)
     def wrapped(request, *args, **kwargs):
         if not request.user.is_authenticated():
+            request.session['_next'] = request.build_absolute_uri()
             return HttpResponseRedirect(get_login_url())
         if not request.user.is_staff:
             return render_to_response('sentry/missing_permissions.html', status=400)
@@ -142,6 +172,7 @@ def permission_required(perm):
         @wraps(func)
         def _wrapped(request, *args, **kwargs):
             if not request.user.is_authenticated():
+                request.session['_next'] = request.build_absolute_uri()
                 return HttpResponseRedirect(get_login_url())
             if not request.user.has_perm(perm):
                 return render_to_response('sentry/missing_permissions.html', status=400)
